@@ -4,9 +4,6 @@ Copyright (c) 2015 Microsoft Corporation
 
 --*/
 
-#ifndef Z3_bool_opt
-#define Z3_bool_opt Z3_bool
-#endif
 
 #ifndef Z3_API
 # ifdef __GNUC__
@@ -20,6 +17,6 @@ Copyright (c) 2015 Microsoft Corporation
 #define DEFINE_TYPE(T) typedef struct _ ## T *T
 #endif
 
-#ifndef DEFINE_VOID
-#define DEFINE_VOID(T) typedef void* T
+#ifndef Z3_DECLARE_CLOSURE
+#define Z3_DECLARE_CLOSURE(_NAME_,_RETURN_,_ARGS_) typedef _RETURN_ _NAME_ _ARGS_
 #endif
